@@ -26,10 +26,11 @@ import json
 from base import BaseMockTests, MockResponse
 
 from goose import Goose
-from goose.images.image import Image
 from goose.utils import FileHelper
 from goose.configuration import Configuration
-from goose.text import StopWordsChinese, StopWordsArabic
+from goose.text import StopWordsChinese
+from goose.text import StopWordsArabic
+from goose.text import StopWordsKorean
 
 
 CURRENT_PATH = os.path.dirname(os.path.abspath(__file__))
@@ -71,13 +72,14 @@ class TestExtractionBase(BaseMockTests):
         """\
 
         """
-        # TODO : handle verbose level in tests
+        # # TODO : handle verbose level in tests
         # print "\n=======================::. ARTICLE REPORT %s .::======================\n" % self.id()
         # print 'expected_value (%s) \n' % len(expected_value)
         # print expected_value
         # print "-------"
         # print 'result_value (%s) \n' % len(result_value)
         # print result_value
+
         # cleaned_text is Null
         msg = u"Resulting article text was NULL!"
         self.assertNotEqual(result_value, None, msg=msg)
@@ -108,19 +110,6 @@ class TestExtractionBase(BaseMockTests):
         for tag in result_value:
             self.assertTrue(tag in expected_value)
 
-    def assert_top_image(self, field, expected_value, result_value):
-        # test if the result value
-        # is an Goose Image instance
-        msg = u"Result value is not a Goose Image instance"
-        self.assertTrue(isinstance(result_value, Image), msg=msg)
-
-        # result_value should be the image src
-        result_value = result_value.src
-
-        # check
-        msg = u"Returned Image is not the one expected"
-        self.assertEqual(expected_value, result_value, msg=msg)
-
     def runArticleAssertions(self, article, fields):
         """\
 
@@ -158,6 +147,7 @@ class TestExtractionBase(BaseMockTests):
         # basic configuration
         # no image fetching
         config = self.getConfig()
+        self.parser = config.get_parser()
 
         # target language
         # needed for non english language most of the time
@@ -270,7 +260,6 @@ class TestExtractions(TestExtractionBase):
     #     article = self.getArticle()
     #     fields = ['cleaned_text']
     #     self.runArticleAssertions(article=article, fields=fields)
-
     def test_time(self):
         article = self.getArticle()
         fields = ['cleaned_text', 'title']
@@ -341,6 +330,11 @@ class TestExtractions(TestExtractionBase):
         fields = ['cleaned_text']
         self.runArticleAssertions(article=article, fields=fields)
 
+    def test_gizmodo1(self):
+        article = self.getArticle()
+        fields = ['cleaned_text', 'meta_description', 'meta_keywords']
+        self.runArticleAssertions(article=article, fields=fields)
+
 
 class TestExtractWithUrl(TestExtractionBase):
 
@@ -376,6 +370,19 @@ class TestExtractArabic(TestExtractionBase):
         self.runArticleAssertions(article=article, fields=fields)
 
 
+class TestExtractKorean(TestExtractionBase):
+
+    def getConfig(self):
+        config = super(TestExtractKorean, self).getConfig()
+        config.stopwords_class = StopWordsKorean
+        return config
+
+    def test_donga_korean(self):
+        article = self.getArticle()
+        fields = ['cleaned_text', 'meta_description', 'meta_keywords']
+        self.runArticleAssertions(article=article, fields=fields)
+
+
 class TestExtractionsRaw(TestExtractions):
 
     def extract(self, instance):
